import request from '@/utils/request';

//分页查询活动宣传
export function queryActivityPage(params:any){
  return request({
    url: '/vision_examine/activity/queryActivityPage' ,
    method: 'get',
    params: params
  });
}


//新增活动宣传
export function addActivity(formData:any){
  return request({
    url:'/vision_examine/activity/addActivity' ,
    method: 'post',
    data: formData,
    headers: {
      'Content-Type': 'multipart/form-data'
    }
  });
}
//修改活动宣传
export function updateActivity(formData:any){
  return request({
    url:'/vision_examine/activity/updateActivity' ,
    method: 'post',
    data: formData,
    headers: {
      'Content-Type': 'multipart/form-data'
    }
  });
}

//删除活动宣传
export function delActivity(queryParams:any){
  return request({
    url:'/vision_examine/activity/delActivity' ,
    method: 'post',
    params: queryParams
  });
}

//修改活动宣传状态
export function updateActivityStatus(data:any){
  return request({
    url:'/vision_examine/activity/updateActivityStatus' ,
    method: 'post',
    data: data,
  });
}


